window.Gleam.initSearch([{"doc":"glacier","title":"glacier","content":"# Glacier · Gleam Incremental Interactive Unit Testing\n\n[![Hex Package](https://img.shields.io/hexpm/v/glacier?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glacier)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glacier/)\n[![Licence](https://img.shields.io/hexpm/l/glacier?color=ffaff3&amp;label=%F0%9F%93%83)](https://github.com/inoas/glacier/blob/main/LICENCE)\n\n**Glacier** brings incremental interactive unit testing to [Gleam](https://gleam.run).\nIt is meant as a drop-in replacement for [Gleeunit](https://hexdocs.pm/gleeunit) and depends on a fork of it.\n\n&lt;figure&gt;\n\t&lt;img src=&quot;https://raw.githubusercontent.com/inoas/glacier/main/glacier-logo.png&quot; alt=&quot;Glacier Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n  &lt;figcaption&gt;&lt;i&gt;&lt;small&gt;Glacier: &lt;a href=&quot;https://en.wikipedia.org/wiki/Glacier&quot;&gt;«A persistent body of dense ice that is constantly moving under its own weight.»&lt;/a&gt;&lt;/small&gt;&lt;/i&gt;&lt;/figcaption&gt;\n&lt;/figure&gt;\n\n## Quick start\n\n1. Open `gleam.toml` and remove `gleeunit` from the dependencies.\n2. Run `gleam add glacier --dev`.\n3. Open `./test/YOUR_PROJECT.gleam` and replace `import gleeunit` with `import glacier` and `gleeunit.main()` with `glacier.main()`.\n4. Run `gleam test --target erlang -- --glacier` or `gleam test --target javascript -- --glacier`.\n5. Save a `src` or `test` module and watch associated tests to re-run.\n\n*Notice: On Linux [**inotify**](https://en.wikipedia.org/wiki/Inotify) must be installed.*\n\n## Upgrading Glacier\n\nMake sure to run `gleam clean` after upgrading Glacier as a dependency.\n\n## Introduction\n\n**Glacier** differs from **Gleeunit** insofar, that it let&#39;s you:\n\n1. Pass in the `glacier` flag like so: `gleam test -- --glacier`, save a module and only related tests will rerun.\n2. Or Pass in a specific unit test modules to rerun `gleam test -- test/my_module_test.gleam`.\n3. If `gleam test` is passed without any `--`-arguments it behaves the same as **Gleeunit**.\n4. You can still pass in `--target erlang` or `--target javascript` like so `gleam test --target erlang -- --glacier`, or like `gleam test --target javascript -- test/my_module_test.gleam`.\n\nTo enable this behavior, all you have to do is add **Glacier** as a dev dependency, aka `gleam add glacier --dev`, open `./test/YOUR_PROJECT.gleam` and replace `gleeunit.main()` with `glacier.main()`.\n\n*Note: `gleam test` must only be executed from the base project directory!*\n\n### Testing against Erlang &amp; JavaScript\n\nRun `gleam test --target erlang -- --glacier` and `gleam test --target javascript -- --glacier` in two terminals side by side.\n\n## Caveats, Requirements &amp; Installation\n\n### Caveats\n\n- `./src` and `./test` source files with white spaces will not pass detection.\n- Behavior towards `./src` and `./test` source files with non-alphanumeric characters is not tested, and generally unsupported.\n\n### Requirements\n\nRequires Gleam 0.26 or later.\n\n#### Target specific requirements\n\n- Erlang/OTP 25 (lower may or may not run)\n- NodeJS 18 LTS+ (lower may or may not run)\n- Deno v1.30.0+ (lower does not run)\n\n#### Target Erlang\n\nDevelopment and testing only happens on very recent stable Erlang/OTP versions, and thus may or may not run on previous versions.\n\nDepends on [fs](https://hexdocs.pm/fs/):\n\n- Linux [relies](https://github.com/synrc/fs#backends) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n#### Target JavaScript/NodeJS/Deno\n\nDevelopment and testing only happens on very recent NodeJS LTS versions, and thus may or may not run on previous versions.\n\nDepends on [`fsPromises.watch`](https://nodejs.org/api/fs.html#fspromiseswatchfilename-options):\n\n- Linux: [relies](https://nodejs.org/docs/latest-v18.x/api/fs.html#fs_caveats) on [**inotify**](https://en.wikipedia.org/wiki/Inotify).\n- Mac: Should work out of the box.\n- Windows: Should work out of the box.\n\n### Installation\n\nThis package is [available on hex.pm](https://hex.pm/packages/glacier) can be added to your Gleam project:\n\n1. Open `.gleam.toml` and remove the `gleeunit` dependency because `Glacier` will fetch its own gleeunit fork.\n2. Run `gleam add glacier --dev`.\n\n## Usage\n\n1. Open `./test/YOUR_PROJECT.gleam` and replace `import gleeunit` with `import glacier` and `gleeunit.main()` with `glacier.main()`.\n2. Run `gleam test -- --glacier`, then:\n   - Save any test module (within `./test`) file to re-run that single test\n   - Save any src module (within `./src`) to run all associated tests. Associated tests are test modules where the module is imported or where any of the module&#39;s imports and their import&#39;s imports (import chain) are imported into.\n3. Optional: You may find and replace all `import gleeunit/should` with `import glacier/should` and remove `gleeunit` from your dependencies in `gleam.toml`.\n\n## Documentation\n\nDocumentation can be found at &lt;https://hexdocs.pm/glacier&gt;.\n\n### How does it work?\n\n1. `gleam test` passes through `glacier.main()` and simply executes `gleeunit.main()` as if **Gleeunit** was used directly.\n2. `gleam test -- test_module_a test_module_b` passes through `glacier.main()` and executes `gleeunit.test_modules(modules_list)` where `modules_list` is `[&quot;foo&quot;, &quot;bar&quot;]`. The given modules are checked if they exist as either `.gleam` or `.erl` test module files and then **Gleeunit** runs these test modules.\n3. `gleam test -- --glacier` enters `glacier.main()` and starts a file watcher: Upon changes in module files in `./test` it just passes those through as `gleam test -- changed_test_module`(so re-saving test files executes the single test), and if a module file in `./src` got changed it parses that changed module file for any imported modules and puts the module and all chained imported modules in a distinct list of modules that should be tested. Then all test module files are read and imports of those are gathered one by one and cross matched against that list. The result is a list of test modules that need to be run, which then gets done by executing a shell call similar to `gleam test -- detected_test_module_a detected_test_module_b detected_test_module_c etc`, aka jump to step `2`.\n\n## Developing Glacier\n\n```sh\ngit clone https://github.com/inoas/glacier.git\ncd glacier\n```\n\nSee all [open issues](https://github.com/inoas/glacier/issues) on GitHub if you want to help out.\n\n### Demo for target Erlang\n\n```sh\n# Traditional test runs\ngleam test --target erlang\ngleam test --target erlang -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target erlang -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n### Demo for target JavaScript/NodeJS\n\n```sh\n# Traditional test runs\ngleam test --target javascript\ngleam test --target javascript -- test/glacier_demo/glacier_demo_module_a_test.gleam\n\n# Incremental interactive test\ngleam test --target javascript -- --glacier\n# Re-save ./src/glacier_demo/glacier_demo_module_a.gleam\n```\n\n## License\n\n[Apache 2.0](./LICENCE)\n","url":"index.html"},{"doc":"glacier","title":"glacier","content":"# Changelog\n\n## 0.6.0\n\n- With Gleam 0.26 supporting *Deno*, so does Glacier\n\n## 0.5.0\n\n- Added fixes and work arounds so that glacier runs with Gleam 0.26.0\n- Glacier might run on Deno might (or might not) run once Gleam 0.26.1 is out\n\n## 0.4.1\n\n- Fix readme.\n\n## 0.4.0\n\n- Remove internal verbatim copy to `gleeunit` and depend on a fork:\n  [`glacier_gleeunit`](https://hex.pm/glacier_gleeunit).\n\n## 0.3.1\n\n- Fix Changelog.\n\n## 0.3.0\n\n- Fix detection of unqualified imports.\n- Fix detection of aliased imports.\n- Fix detection of renames.\n- Files with white spaces are now ignored.\n- Improved readme.\n- Force rebased on `lpil/gleeunit` to keep all contributor history alive.\n  - This was required because initially `Glacier` was supposed to depend on\n    a patched `Gleeunit`, but the idea of patching `Gleeunit` a bit was\n    rejected by the `Gleeunit` team. While this may not be strictly necessary\n    this honors previous contributions transparently.\n  - This was a quick and dirty process where I saved a lot of time by _not_\n    fixing any merges and instead just adding them without touching them\n    including the diff noise. As a consequence single commits if checked out\n    might not run any more. After the dirty rebase I&#39;ve commited the\n    source code state equvialent to `0.2.7` to restore functionality.\n- Proper BE noun instead of an AE one for the `LICENCE` file and naming.\n\n## 0.2.7\n\n- Fix `MaxListenersExceededWarning: Possible EventEmitter memory leak detected` (#4).\n- Cleanup `README.md`.\n\n## 0.2.6\n\n- Instruct to use `gleam add glacier --dev` to add as a dev dependency, only.\n\n## 0.2.5\n\n- Readme: Explain that `gleeunit` is optional if `glacier` is installed if `gleeunit/should` is replaced by `glacier/should`.\n\n## 0.2.4\n\n- More compatibility changes to run `glacier` alongside `gleeunit`:\n  Added `glacier/should` which is a renamed `gleeunit/should`.\n\n## 0.2.3\n\n- Remove code that did nothing.\n\n## 0.2.2\n\n- Fixed `README.md`.\n\n## 0.2.1\n\n- Fixed `README.md`.\n\n## 0.2.0\n\n- Added `CHANGELOG.md`.\n- Renamed internal gleeunit fork to gleeunit2 to avoid collisions.\n- JavaScript: File renames are picked up by the watcher.\n- Replaced `glacier.run()` with `glacier.main()` as latter did not make sense before.\n- Fixed `README.md`.\n- Fixed the logo to work across hexpm and github and shields badges.\n\n## 0.1.0\n\n- _Ex post_ rebased on `lpil/gleeunit`\n\n### Gleeunit v0.8\n\n- `should.be_ok` and `should.be_error` now unwrap the result argument\n\n### Gleeunit v0.7.2 - 2022-11-19\n\n- Update for Gleam v0.25.0.\n\n### Gleeunit v0.7.1 - 2022-11-11\n\n- Fixed a bug where project names containing numbers would not run correctly on\n  JavaScript.\n\n### Gleeunit v0.7.0 - 2022-09-24\n\n- Line numbers are printed on JS for assertions.\n\n### Gleeunit v0.6.2 - 2022-07-15\n\n- Fixed a bug where assertions in JavaScript tests could fail to report an\n  error due to them being async.\n\n### Gleeunit v0.6.1 - 2022-01-26\n\n- Fixed a bug where failed tests on the JavaScript target would crash the `main`\n  function.\n- Fixed a bug where tests on the JavaScript target could succeed regardless of\n  return value.\n\n### Gleeunit v0.6.0 - 2022-01-09\n\n- Added support for OTP versions below 23.\n- Added support for running tests on the JavaScript target.\n\n### Gleeunit v0.5.0 - 2021-12-05\n\n- Updated for Gleam v0.18.0.\n- Added `gleeunit/should` module containing assertions.\n\n### Gleeunit v0.4.0 - 2021-11-01\n\n- Slightly improved failure format.\n\n### Gleeunit v0.3.0 - 2021-10-31\n\n- Fixed Hex package which was missing some files.\n\n### Gleeunit v0.2.0 - 2021-10-31\n\n- `gleeunit.discover_and_run_tests` removed.\n- `gleeunit.main` added.\n\n### Gleeunit v0.1.0 - 2021-10-31\n\n- Initial release.\n","url":"changelog.html"},{"doc":"glacier","title":"glacier","content":"","url":"license.html"},{"doc":"glacier_demo/glacier_demo_module_a","title":"function_1","content":"pub fn function_1() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_a.function_1\nglacier_demo/glacier_demo_module_a function_1","url":"glacier_demo/glacier_demo_module_a.html#function_1"},{"doc":"glacier_demo/glacier_demo_module_a","title":"function_2","content":"pub fn function_2() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_a.function_2\nglacier_demo/glacier_demo_module_a function_2","url":"glacier_demo/glacier_demo_module_a.html#function_2"},{"doc":"glacier_demo/glacier_demo_module_a","title":"glacier_demo/glacier_demo_module_a","content":"","url":"glacier_demo/glacier_demo_module_a.html"},{"doc":"glacier_demo/glacier_demo_module_d","title":"main","content":"pub fn main() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_d.main\nglacier_demo/glacier_demo_module_d main","url":"glacier_demo/glacier_demo_module_d.html#main"},{"doc":"glacier_demo/glacier_demo_module_d","title":"glacier_demo/glacier_demo_module_d","content":"","url":"glacier_demo/glacier_demo_module_d.html"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_5","content":"pub fn function_5() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_5\nglacier_demo/glacier_demo_module_c function_5","url":"glacier_demo/glacier_demo_module_c.html#function_5"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_6","content":"pub fn function_6() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_6\nglacier_demo/glacier_demo_module_c function_6","url":"glacier_demo/glacier_demo_module_c.html#function_6"},{"doc":"glacier_demo/glacier_demo_module_c","title":"function_a","content":"pub fn function_a() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_c.function_a\nglacier_demo/glacier_demo_module_c function_a","url":"glacier_demo/glacier_demo_module_c.html#function_a"},{"doc":"glacier_demo/glacier_demo_module_c","title":"glacier_demo/glacier_demo_module_c","content":"","url":"glacier_demo/glacier_demo_module_c.html"},{"doc":"glacier_demo/glacier_demo_module_b","title":"a","content":"pub fn a() -&gt; String\n\nSynonyms:\nglacier_demo/glacier_demo_module_b.a\nglacier_demo/glacier_demo_module_b a","url":"glacier_demo/glacier_demo_module_b.html#a"},{"doc":"glacier_demo/glacier_demo_module_b","title":"function_3","content":"pub fn function_3() -&gt; Int\n function doc import in_fn_docblock should be ignored\nSynonyms:\nglacier_demo/glacier_demo_module_b.function_3\nglacier_demo/glacier_demo_module_b function_3","url":"glacier_demo/glacier_demo_module_b.html#function_3"},{"doc":"glacier_demo/glacier_demo_module_b","title":"function_4","content":"pub fn function_4() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_b.function_4\nglacier_demo/glacier_demo_module_b function_4","url":"glacier_demo/glacier_demo_module_b.html#function_4"},{"doc":"glacier_demo/glacier_demo_module_b","title":"glacier_demo/glacier_demo_module_b","content":" module doc import in_module_docblock should be ignored","url":"glacier_demo/glacier_demo_module_b.html"},{"doc":"glacier","title":"ModuleKind","content":"pub type ModuleKind {\n  SrcModuleKind\n  TestModuleKind\n}\n Atom to internally differentiate between Src and Test modules.\n Public because the FFIs rely on it.\n\nSrcModuleKind\n\n\nTestModuleKind\n\n\nSynonyms:\nglacier.ModuleKind\nglacier ModuleKind","url":"glacier.html#ModuleKind"},{"doc":"glacier","title":"main","content":"pub fn main() -&gt; Nil\n Runs either Glacier or Gleeunit bundled as `gleeunit`, depending on\n the given command line arguments.\n\nSynonyms:\nglacier.main\nglacier main","url":"glacier.html#main"},{"doc":"glacier","title":"glacier","content":"","url":"glacier.html"},{"doc":"glacier_demo/glacier_demo_references_a","title":"function_1","content":"pub fn function_1() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_references_a.function_1\nglacier_demo/glacier_demo_references_a function_1","url":"glacier_demo/glacier_demo_references_a.html#function_1"},{"doc":"glacier_demo/glacier_demo_references_a","title":"function_2","content":"pub fn function_2() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_references_a.function_2\nglacier_demo/glacier_demo_references_a function_2","url":"glacier_demo/glacier_demo_references_a.html#function_2"},{"doc":"glacier_demo/glacier_demo_references_a","title":"glacier_demo/glacier_demo_references_a","content":"","url":"glacier_demo/glacier_demo_references_a.html"},{"doc":"glacier_demo/hello","title":"function_1","content":"pub fn function_1() -&gt; String\n\nSynonyms:\nglacier_demo/hello.function_1\nglacier_demo/hello function_1","url":"glacier_demo/hello.html#function_1"},{"doc":"glacier_demo/hello","title":"glacier_demo/hello","content":"","url":"glacier_demo/hello.html"},{"doc":"glacier_demo/glacier_demo_module_unqualifying","title":"proxied_function_5","content":"pub fn proxied_function_5() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_unqualifying.proxied_function_5\nglacier_demo/glacier_demo_module_unqualifying proxied_function_5","url":"glacier_demo/glacier_demo_module_unqualifying.html#proxied_function_5"},{"doc":"glacier_demo/glacier_demo_module_unqualifying","title":"glacier_demo/glacier_demo_module_unqualifying","content":"","url":"glacier_demo/glacier_demo_module_unqualifying.html"},{"doc":"glacier_demo/glacier_demo_module_e","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nglacier_demo/glacier_demo_module_e.main\nglacier_demo/glacier_demo_module_e main","url":"glacier_demo/glacier_demo_module_e.html#main"},{"doc":"glacier_demo/glacier_demo_module_e","title":"glacier_demo/glacier_demo_module_e","content":"","url":"glacier_demo/glacier_demo_module_e.html"},{"doc":"glacier_demo/glacier_demo_module_aliasing_c","title":"proxied_function_5","content":"pub fn proxied_function_5() -&gt; Int\n\nSynonyms:\nglacier_demo/glacier_demo_module_aliasing_c.proxied_function_5\nglacier_demo/glacier_demo_module_aliasing_c proxied_function_5","url":"glacier_demo/glacier_demo_module_aliasing_c.html#proxied_function_5"},{"doc":"glacier_demo/glacier_demo_module_aliasing_c","title":"glacier_demo/glacier_demo_module_aliasing_c","content":"","url":"glacier_demo/glacier_demo_module_aliasing_c.html"},{"doc":"glacier/should","title":"be_error","content":"pub fn be_error(result: Result(a, b)) -&gt; b\n\nSynonyms:\nglacier/should.be_error\nglacier/should be_error","url":"glacier/should.html#be_error"},{"doc":"glacier/should","title":"be_ok","content":"pub fn be_ok(result: Result(a, b)) -&gt; a\n\nSynonyms:\nglacier/should.be_ok\nglacier/should be_ok","url":"glacier/should.html#be_ok"},{"doc":"glacier/should","title":"equal","content":"pub fn equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nglacier/should.equal\nglacier/should equal","url":"glacier/should.html#equal"},{"doc":"glacier/should","title":"not_equal","content":"pub fn not_equal(a: a, b: a) -&gt; Nil\n\nSynonyms:\nglacier/should.not_equal\nglacier/should not_equal","url":"glacier/should.html#not_equal"},{"doc":"glacier/should","title":"glacier/should","content":" A proxy module into gleeunit/should\n","url":"glacier/should.html"}]);